/*
  Example for Stepper 4 Click

  Date          : August 2017
  Author        : Irena Blagojevic

  Test configuration AVR :
    
  MCU              : ATMEGA32
  Dev. Board       : EasyAVR v7 
  AVR Compiler ver : v.7.0.0

  Description :

  Demonstrates how to use Stepper 4 click to move a stepper motor. First
  the speed is set, given in number of steps per revolution. Afterwards
  the motor is moved using STEPPER_step function, passing it the number
  of desired steps. If that number is negative, the motor moves CCW,
  otherwise it moves CW.

*/

#include "MIKROBUS_framework.h"
#include "__STEPPER_Driver.h"

void InitTimer0()
{
    SREG_I_bit = 1;
    OCR0       = 99;
    TCCR0      = 0x28;
    TCCR0     |= 0x02;
    OCIE0_bit  = 1;
}

void systemInit()
{
    STEPPER_GPIOmap( MIKROBUS1_setAN, MIKROBUS1_setCS, MIKROBUS1_setPWM,
                     MIKROBUS1_setRST, MIKROBUS1_setINT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_AN_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_CS_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_PWM_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_RST_PIN, GPIO_OUTPUT );
    MIKROBUS_gpioDirection( MIKROBUS1, MIKROBUS_INT_PIN, GPIO_OUTPUT );

    InitTimer0();
}

void Stepper_4_Init()
{
    STEPPER_init( 200, 100 );

    STEPPER_setAcc( 5 );
    STEPPER_setDec( 5 );
}

void Stepper_4_Task()
{
    STEPPER_setSpeed( 200 );
    STEPPER_step( 400 );
    Delay_ms( 200 );
    STEPPER_setSpeed( 100 );
    STEPPER_step( -200 );
}

void main()
{
    systemInit();
    Stepper_4_Init();

    Stepper_4_Task();
}

void Timer0Overflow_ISR() org IVT_ADDR_TIMER0_COMP {
    STEPPER_handler();
}
